Changelog
=========

0.2.11
------

- |changed| unpin version of sphinx
- |added| new autodoc Documenters to work with sphinx ~ 5

0.2.10
------

- |changed| pin version of sphinx to 4.5.0.

0.2.9
-----

- |changed| pin version of jinja to 3.0.3.

0.2.8
-----

- |added| admonition deprecated.
- |removed| useless custom.css.

0.2.7
-----

- |added| move travis ci to github actions.

0.2.6
-----

- |added| flag to disable version check.

0.2.5
-----

- |fixed| avoid overlapping content and right sidebar.

0.2.4
-----

- |added| home button link.

0.2.3
-----

- |fixed| :ref links.

0.2.0
-----

- |removed| Python 2 support.
- |added| Python 3.7 and 3.8 testing.

0.1.5
-----

- |fixed| package release on TravisCI.

0.1.4
-----

- |fixed| sdist packaging.

0.1.3
-----

- |fixed| TravisCI deployment.

0.1.2
-----

- |fixed| Image alignment flags.
- |fixed| ReadtheDocs injected version box styling.

.. |fixed| image:: https://img.shields.io/badge/-fixed-success.svg
              :class: badge
.. |added| image:: https://img.shields.io/badge/-added-seagreen.svg
              :class: badge
.. |changed| image:: https://img.shields.io/badge/-changed-informational.svg
                :class: badge
.. |removed| image:: https://img.shields.io/badge/-removed-slategrey.svg
                :class: badge
.. |deprecated| image:: https://img.shields.io/badge/-deprecated-lightgrey.svg
                   :class: badge
.. |security| image:: https://img.shields.io/badge/-security-tomato.svg
                 :class: badge
